@@ -1977,20 +1977,20 @@ general_location_set_dict = [
 
 
 def test_general_location_set_dict(loc_sets):
-    assert loc_sets.hoofdloc.general_location_sets_dict == general_location_set_dict
-    assert loc_sets.subloc.general_location_sets_dict == general_location_set_dict
-    assert loc_sets.waterstandloc.general_location_sets_dict == general_location_set_dict
-    assert loc_sets.psloc.general_location_sets_dict == general_location_set_dict
-    assert loc_sets.mswloc.general_location_sets_dict == general_location_set_dict
+    assert loc_sets.hoofd_loc.general_location_sets_dict == general_location_set_dict
+    assert loc_sets.sub_loc.general_location_sets_dict == general_location_set_dict
+    assert loc_sets.waterstand_loc.general_location_sets_dict == general_location_set_dict
+    assert loc_sets.ps_loc.general_location_sets_dict == general_location_set_dict
+    assert loc_sets.msw_loc.general_location_sets_dict == general_location_set_dict
 
 
 def test_unique_validation_attributes(loc_sets):
     def _attribs(loc_set: LocationSetBase):
         return loc_set.get_validation_attributes(int_pars=None)
 
-    assert _attribs(loc_sets.hoofdloc) and _attribs(loc_sets.subloc) and _attribs(loc_sets.waterstandloc)
-    assert _attribs(loc_sets.mswloc) == [] and _attribs(loc_sets.psloc) == []
-    assert _attribs(loc_sets.hoofdloc) != _attribs(loc_sets.subloc) != _attribs(loc_sets.mswloc)
+    assert _attribs(loc_sets.hoofd_loc) and _attribs(loc_sets.sub_loc) and _attribs(loc_sets.waterstand_loc)
+    assert _attribs(loc_sets.msw_loc) == [] and _attribs(loc_sets.ps_loc) == []
+    assert _attribs(loc_sets.hoofd_loc) != _attribs(loc_sets.sub_loc) != _attribs(loc_sets.msw_loc)
 
 
 def test_unique_csvfile_meta(loc_sets):
@@ -1998,37 +1998,37 @@ def test_unique_csvfile_meta(loc_sets):
         return [loc_set for loc_set in general_location_set_dict if loc_set["id"] == _loc_set.fews_name][0]["csvFile"]
 
     assert (
-        loc_sets.hoofdloc.csv_file_meta
-        and loc_sets.subloc.csv_file_meta  # noqa
-        and loc_sets.waterstandloc.csv_file_meta  # noqa
-        and loc_sets.mswloc.csv_file_meta  # noqa
-        and loc_sets.psloc.csv_file_meta  # noqa
+        loc_sets.hoofd_loc.csv_file_meta
+        and loc_sets.sub_loc.csv_file_meta  # noqa
+        and loc_sets.waterstand_loc.csv_file_meta  # noqa
+        and loc_sets.msw_loc.csv_file_meta  # noqa
+        and loc_sets.ps_loc.csv_file_meta  # noqa
     )
     assert (
-        loc_sets.hoofdloc.csv_file_meta  # noqa
-        != loc_sets.subloc.csv_file_meta  # noqa
-        != loc_sets.waterstandloc.csv_file_meta  # noqa
-        != loc_sets.mswloc.csv_file_meta  # noqa
-        != loc_sets.psloc.csv_file_meta  # noqa
+        loc_sets.hoofd_loc.csv_file_meta  # noqa
+        != loc_sets.sub_loc.csv_file_meta  # noqa
+        != loc_sets.waterstand_loc.csv_file_meta  # noqa
+        != loc_sets.msw_loc.csv_file_meta  # noqa
+        != loc_sets.ps_loc.csv_file_meta  # noqa
     )
-    assert loc_sets.hoofdloc.csv_file_meta == _meta(
-        _loc_set=loc_sets.hoofdloc, general_location_set_dict=general_location_set_dict
+    assert loc_sets.hoofd_loc.csv_file_meta == _meta(
+        _loc_set=loc_sets.hoofd_loc, general_location_set_dict=general_location_set_dict
     )
-    assert loc_sets.subloc.csv_file_meta == _meta(
-        _loc_set=loc_sets.subloc, general_location_set_dict=general_location_set_dict
+    assert loc_sets.sub_loc.csv_file_meta == _meta(
+        _loc_set=loc_sets.sub_loc, general_location_set_dict=general_location_set_dict
     )
-    assert loc_sets.waterstandloc.csv_file_meta == _meta(
-        _loc_set=loc_sets.waterstandloc, general_location_set_dict=general_location_set_dict,
+    assert loc_sets.waterstand_loc.csv_file_meta == _meta(
+        _loc_set=loc_sets.waterstand_loc, general_location_set_dict=general_location_set_dict,
     )
-    assert loc_sets.psloc.csv_file_meta == _meta(
-        _loc_set=loc_sets.psloc, general_location_set_dict=general_location_set_dict
+    assert loc_sets.ps_loc.csv_file_meta == _meta(
+        _loc_set=loc_sets.ps_loc, general_location_set_dict=general_location_set_dict
     )
-    assert loc_sets.mswloc.csv_file_meta == _meta(
-        _loc_set=loc_sets.mswloc, general_location_set_dict=general_location_set_dict
+    assert loc_sets.msw_loc.csv_file_meta == _meta(
+        _loc_set=loc_sets.msw_loc, general_location_set_dict=general_location_set_dict
     )
 
 
 def test_unique_attribute_files(loc_sets):
-    assert loc_sets.hoofdloc.attrib_files and loc_sets.subloc.attrib_files and loc_sets.waterstandloc.attrib_files
-    assert loc_sets.mswloc.attrib_files == [] and loc_sets.psloc.attrib_files == []
-    assert loc_sets.hoofdloc.attrib_files != loc_sets.subloc.attrib_files != loc_sets.waterstandloc.attrib_files
+    assert loc_sets.hoofd_loc.attrib_files and loc_sets.sub_loc.attrib_files and loc_sets.waterstand_loc.attrib_files
+    assert loc_sets.msw_loc.attrib_files == [] and loc_sets.ps_loc.attrib_files == []
+    assert loc_sets.hoofd_loc.attrib_files != loc_sets.sub_loc.attrib_files != loc_sets.waterstand_loc.attrib_files
